onlyInProduction property
If true (default), Cache-Control headers will only be set if the application is in production mode.
Implementation
final bool onlyInProduction;
If true (default), Cache-Control headers will only be set if the application is in production mode.
final bool onlyInProduction;