useBuffer property
If true (default: true), then files will be opened as streams and piped into the request.
If not, the response buffer will be used instead.
Implementation
final bool useBuffer;
If true (default: true), then files will be opened as streams and piped into the request.
If not, the response buffer will be used instead.
final bool useBuffer;